# Sxolar API Documentation

The `sxolar` package provides a simple interface to search for papers on the arXiv. The package is designed to be simple
and intuitive to use, and is built on top of the `arxiv` package.

The package provides two main classes: `Author` and `Title`. These classes can be used to search for papers by author
or by title, respectively. The package also provides a `Query` class, which can be used to combine multiple search
criteria.

## Sxolar ArXiv API 

- [Low-level ArXiv wrappers](api/arxiv.md)
- [High-level Interface](api/search.md)

## Sxolar Utilities

- [Google Mail Sending Utilities](util/gmail.md)
